"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useLoggerApi = exports.LoggerContext = void 0;
var jsx_runtime_1 = require("react/jsx-runtime");
var react_1 = require("react");
var valid_types_1 = require("valid-types");
var bsod_1 = __importDefault(require("./bsod"));
var logger_1 = require("./logger");
var stack_1 = require("./stack");
var utils_1 = require("./utils");
exports.LoggerContext = (0, react_1.createContext)(null);
var isBackend = function () { return typeof window === 'undefined'; };
var useLoggerApi = function () {
    var ctx = (0, react_1.useContext)(exports.LoggerContext);
    return {
        getStackData: ctx.getStackData,
        triggerError: ctx.onError,
    };
};
exports.useLoggerApi = useLoggerApi;
// eslint-disable-next-line import/no-default-export
var LoggerContainer = /** @class */ (function (_super) {
    __extends(LoggerContainer, _super);
    function LoggerContainer(props) {
        if (props === void 0) { props = {
            active: true,
            bsodActive: true,
            getCurrentDate: utils_1.getCurrentDate,
            limit: 25,
            logger: logger_1.logger,
            sessionID: false,
        }; }
        var _this = _super.call(this, props) || this;
        _this.__hasCriticalError = false;
        _this.handlerError = function (e) {
            var lineno = e.lineno, error = e.error;
            _this.unbindActions();
            if (!_this.__hasCriticalError) {
                _this.__hasCriticalError = true;
                var stackData = (0, stack_1.onCriticalError)(_this.stack, logger_1.logger.getStackCollection(), {
                    getCurrentDate: _this.props.getCurrentDate,
                    onPrepareStack: _this.props.onPrepareStack,
                }, error, lineno);
                _this.onError(stackData);
                _this.setState({
                    bsod: true,
                });
            }
        };
        _this._onMouseDown = function (e) {
            _this.stack.mousePressed = e && e.button;
        };
        _this._onKeyDown = function (e) {
            _this.stack.keyboardPressed = e && e.code;
        };
        _this._onKeyUp = function () {
            setTimeout(function () {
                _this.stack.keyboardPressed = null;
            });
        };
        _this._onMouseUp = function () {
            setTimeout(function () {
                _this.stack.mousePressed = null;
            });
        };
        _this.getStackData = function () {
            return (0, stack_1.getStackData)(_this.stack, logger_1.logger.getStackCollection(), {
                getCurrentDate: _this.props.getCurrentDate,
                onPrepareStack: _this.props.onPrepareStack,
            });
        };
        _this.onError = function (stackData) {
            if (typeof _this.props.onError === 'function') {
                _this.props.onError(stackData);
            }
        };
        _this.closeBsod = function () {
            _this.setState({
                bsod: false,
            });
        };
        _this.state = {
            bsod: false,
        };
        _this.stack = {
            actions: logger_1.logger.getStackCollection().data,
            env: {},
            keyboardPressed: null,
            mousePressed: null,
            onPrepareStack: typeof _this.props.onPrepareStack === 'function' ? _this.props.onPrepareStack : function () { },
            session: {},
            sessionId: undefined,
        };
        var LIMIT = (0, valid_types_1.isNumber)(_this.props.limit) ? _this.props.limit : 25;
        logger_1.logger.setUp({
            active: props.active,
        });
        logger_1.logger.getStackCollection().setLimit(LIMIT);
        if ((0, valid_types_1.isFunction)(_this.props.stdout)) {
            logger_1.logger.setUp({
                stdout: _this.props.stdout,
            });
        }
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        _this.stack.session.start = (0, valid_types_1.isFunction)(_this.props.getCurrentDate) ? _this.props.getCurrentDate() : (0, utils_1.getCurrentDate)();
        if ((0, valid_types_1.isString)(_this.props.sessionID) || (0, valid_types_1.isNumber)(_this.props.sessionID)) {
            _this.stack.sessionId = _this.props.sessionID;
        }
        return _this;
    }
    LoggerContainer.prototype.componentDidMount = function () {
        if (this.props.active && !isBackend()) {
            this.bindActions();
            window.addEventListener('error', this.handlerError);
        }
    };
    LoggerContainer.prototype.componentWillUnmount = function () {
        this.unbindActions();
    };
    LoggerContainer.prototype.bindActions = function () {
        document.addEventListener('mousedown', this._onMouseDown);
        document.addEventListener('mouseup', this._onMouseUp);
        document.addEventListener('keydown', this._onKeyDown);
        document.addEventListener('keyup', this._onKeyUp);
    };
    LoggerContainer.prototype.unbindActions = function () {
        window.removeEventListener('error', this.handlerError);
        document.removeEventListener('keydown', this._onKeyDown);
        document.removeEventListener('keyup', this._onKeyUp);
        document.removeEventListener('mousedown', this._onMouseDown);
        document.removeEventListener('mouseup', this._onMouseUp);
    };
    LoggerContainer.prototype.render = function () {
        var Bsod = (0, react_1.isValidElement)(this.props.bsod) ? this.props.bsod : bsod_1.default;
        return ((0, jsx_runtime_1.jsxs)(exports.LoggerContext.Provider, __assign({ value: {
                getStackData: this.getStackData,
                onError: this.onError,
            } }, { children: [this.props.children, this.props.bsodActive && this.state.bsod && ((0, jsx_runtime_1.jsx)(Bsod, { count: logger_1.logger.getCounter(), onClose: this.closeBsod, stackData: this.getStackData() }))] })));
    };
    return LoggerContainer;
}(react_1.Component));
exports.default = LoggerContainer;
//# sourceMappingURL=logger-container.js.map