import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Component, createContext, isValidElement, useContext } from 'react';
import { isString, isNumber, isFunction } from 'valid-types';
import BsodComponent from './bsod';
import { logger } from './logger';
import { getStackData, onCriticalError } from './stack';
import { getCurrentDate } from './utils';
export const LoggerContext = createContext(null);
const isBackend = () => typeof window === 'undefined';
export const useLoggerApi = () => {
    const ctx = useContext(LoggerContext);
    return {
        getStackData: ctx.getStackData,
        triggerError: ctx.onError,
    };
};
// eslint-disable-next-line import/no-default-export
export default class LoggerContainer extends Component {
    constructor(props = {
        active: true,
        bsodActive: true,
        getCurrentDate,
        limit: 25,
        logger,
        sessionID: false,
    }) {
        super(props);
        this.__hasCriticalError = false;
        this.handlerError = (e) => {
            const { lineno, error } = e;
            this.unbindActions();
            if (!this.__hasCriticalError) {
                this.__hasCriticalError = true;
                const stackData = onCriticalError(this.stack, logger.getStackCollection(), {
                    getCurrentDate: this.props.getCurrentDate,
                    onPrepareStack: this.props.onPrepareStack,
                }, error, lineno);
                this.onError(stackData);
                this.setState({
                    bsod: true,
                });
            }
        };
        this._onMouseDown = (e) => {
            this.stack.mousePressed = e && e.button;
        };
        this._onKeyDown = (e) => {
            this.stack.keyboardPressed = e && e.code;
        };
        this._onKeyUp = () => {
            setTimeout(() => {
                this.stack.keyboardPressed = null;
            });
        };
        this._onMouseUp = () => {
            setTimeout(() => {
                this.stack.mousePressed = null;
            });
        };
        this.getStackData = () => getStackData(this.stack, logger.getStackCollection(), {
            getCurrentDate: this.props.getCurrentDate,
            onPrepareStack: this.props.onPrepareStack,
        });
        this.onError = (stackData) => {
            if (typeof this.props.onError === 'function') {
                this.props.onError(stackData);
            }
        };
        this.closeBsod = () => {
            this.setState({
                bsod: false,
            });
        };
        this.state = {
            bsod: false,
        };
        this.stack = {
            actions: logger.getStackCollection().data,
            env: {},
            keyboardPressed: null,
            mousePressed: null,
            onPrepareStack: typeof this.props.onPrepareStack === 'function' ? this.props.onPrepareStack : () => { },
            session: {},
            sessionId: undefined,
        };
        const LIMIT = isNumber(this.props.limit) ? this.props.limit : 25;
        logger.setUp({
            active: props.active,
        });
        logger.getStackCollection().setLimit(LIMIT);
        if (isFunction(this.props.stdout)) {
            logger.setUp({
                stdout: this.props.stdout,
            });
        }
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        this.stack.session.start = isFunction(this.props.getCurrentDate) ? this.props.getCurrentDate() : getCurrentDate();
        if (isString(this.props.sessionID) || isNumber(this.props.sessionID)) {
            this.stack.sessionId = this.props.sessionID;
        }
    }
    componentDidMount() {
        if (this.props.active && !isBackend()) {
            this.bindActions();
            window.addEventListener('error', this.handlerError);
        }
    }
    componentWillUnmount() {
        this.unbindActions();
    }
    bindActions() {
        document.addEventListener('mousedown', this._onMouseDown);
        document.addEventListener('mouseup', this._onMouseUp);
        document.addEventListener('keydown', this._onKeyDown);
        document.addEventListener('keyup', this._onKeyUp);
    }
    unbindActions() {
        window.removeEventListener('error', this.handlerError);
        document.removeEventListener('keydown', this._onKeyDown);
        document.removeEventListener('keyup', this._onKeyUp);
        document.removeEventListener('mousedown', this._onMouseDown);
        document.removeEventListener('mouseup', this._onMouseUp);
    }
    render() {
        const Bsod = isValidElement(this.props.bsod) ? this.props.bsod : BsodComponent;
        return (_jsxs(LoggerContext.Provider, Object.assign({ value: {
                getStackData: this.getStackData,
                onError: this.onError,
            } }, { children: [this.props.children, this.props.bsodActive && this.state.bsod && (_jsx(Bsod, { count: logger.getCounter(), onClose: this.closeBsod, stackData: this.getStackData() }))] })));
    }
}
//# sourceMappingURL=logger-container.js.map